pub struct PluginRootSnapshot { /* private fields */ }Expand description
Filesystem-independent snapshot of one plugins/ directory.
Implementations
Sourceimpl PluginRootSnapshot
impl PluginRootSnapshot
pub fn new( releases: impl IntoIterator<Item = PluginDescriptor>, instances: impl IntoIterator<Item = PluginRootInstance>, disabled: impl IntoIterator<Item = PluginInstanceId>, ) -> Self
pub fn releases(&self) -> &[PluginDescriptor]
Sourcepub fn with_dependency_choices(self, choices: Vec<DependencyChoice>) -> Self
pub fn with_dependency_choices(self, choices: Vec<DependencyChoice>) -> Self
Adopts named dependency selection with an exact persisted choice set.
pub fn dependency_choices(&self) -> &[DependencyChoice]
Sourcepub const fn dependency_selection_adopted(&self) -> bool
pub const fn dependency_selection_adopted(&self) -> bool
Reports whether this Root has adopted persisted named dependency choices.
pub fn instances(&self) -> &[PluginRootInstance]
pub fn disabled(&self) -> &[PluginInstanceId]