PlanResolutionError

Enum PlanResolutionError 

pub enum PlanResolutionError {
Show 30 variants UnsupportedTerminalPolicy, InvalidTerminalPolicy { detail: String, }, InvalidAuthoring { instance_key: String, }, InvalidRequirementId { consumer_instance: String, requirement_id: String, }, DuplicateRequirementId { consumer_instance: String, requirement_id: String, }, UnsupportedSchemaVersion { expected: u32, actual: u32, }, DuplicatePluginInstance { instance_key: String, }, MissingExecutionLane, InvalidExecutionLane { execution_lane: String, }, DuplicateExecutionLane { execution_lane: String, }, UndeclaredExecutionLane { instance_key: String, execution_lane: String, }, InvalidPluginEntrypoint { instance_key: String, }, DuplicateProvidedCapability { provider_instance: String, capability_id: String, }, DuplicateOperation { provider_instance: String, capability_id: String, operation: String, }, DuplicateRequiredCapability { consumer_instance: String, capability_id: String, }, InvalidConsumerReference { consumer_instance: String, capability_id: String, }, InvalidProviderReference { consumer_instance: String, capability_id: String, provider_instance: String, }, UndeclaredCapabilityRequirement { consumer_instance: String, capability_id: String, }, IncompatibleCapabilityVersion { consumer_instance: String, capability_id: String, required: String, provided: String, provider_instance: String, }, CrossLaneTransferUnsupported { consumer_instance: String, provider_instance: String, capability_id: String, }, CrossLaneInteractionUnsupported { capability_id: String, operation: String, interaction: CapabilityOperationKind, }, MissingOneBinding { consumer_instance: String, capability_id: String, }, AmbiguousOneBinding { consumer_instance: String, capability_id: String, providers: usize, }, AmbiguousOptionalBinding { consumer_instance: String, capability_id: String, providers: usize, }, DuplicateBinding { consumer_instance: String, capability_id: String, provider_instance: String, }, InvalidRequestAdmission { capability_id: String, operation: String, queue_capacity: usize, max_concurrency: usize, }, UnknownAdmissionOperation { capability_id: String, operation: String, }, UnknownOperationInteraction { capability_id: String, operation: String, }, InvalidRestartPolicy { instance_key: String, max_attempts: usize, window: Duration, }, ActivationCycle { instances: Vec<String>, },
}
A reason App Composition could not be materialized into a Plan.

Variants



UnsupportedTerminalPolicy

This Kernel does not yet execute the selected terminal policy.



InvalidTerminalPolicy

Host-essential roots or their materialized closure are invalid.

Fields

detail: String


InvalidAuthoring

Contract version or selected runtime profile is invalid.

Fields

instance_key: String


InvalidRequirementId

A requirement identity is invalid for the selected authoring version.

Fields

consumer_instance: String
requirement_id: String


DuplicateRequirementId

Two declarations share one consumer-local identity.

Fields

consumer_instance: String
requirement_id: String


UnsupportedSchemaVersion

The Plan schema cannot be executed by this Kernel version.

Fields

expected: u32
actual: u32


DuplicatePluginInstance

Two Plugin Instances use the same App-local key.

Fields

instance_key: String


MissingExecutionLane

Every App must declare at least one Execution Lane.



InvalidExecutionLane

An Execution Lane identity is empty or whitespace-only.

Fields

execution_lane: String


DuplicateExecutionLane

Two Execution Lanes use the same App-local identity.

Fields

execution_lane: String


UndeclaredExecutionLane

A Plugin Instance names an Execution Lane absent from the Plan.

Fields

instance_key: String
execution_lane: String


InvalidPluginEntrypoint

A Plugin Instance has no executable entrypoint identity.

Fields

instance_key: String


DuplicateProvidedCapability

A Plugin declares the same provided Capability more than once.

Fields

provider_instance: String
capability_id: String


DuplicateOperation

One endpoint declares an Operation more than once.

Fields

provider_instance: String
capability_id: String
operation: String


DuplicateRequiredCapability

A Plugin declares the same required Capability more than once.

Fields

consumer_instance: String
capability_id: String


InvalidConsumerReference

A binding names a consumer that is not in the Composition.

Fields

consumer_instance: String
capability_id: String


InvalidProviderReference

A binding names a provider that is not in the Composition or does not provide the Capability.

Fields

consumer_instance: String
capability_id: String
provider_instance: String


UndeclaredCapabilityRequirement

A binding exists without a matching consumer requirement.

Fields

consumer_instance: String
capability_id: String


IncompatibleCapabilityVersion

The provider and consumer selected different exact Descriptor versions.

Fields

consumer_instance: String
capability_id: String
required: String
provided: String
provider_instance: String


CrossLaneTransferUnsupported

A binding crosses Execution Lanes but its generated contract types are not transferable.

Fields

consumer_instance: String
provider_instance: String
capability_id: String


CrossLaneInteractionUnsupported

A host Runtime does not implement cross-lane transfer for the selected interaction kind.

Retained so downstream code can classify failures produced by older Runtime versions.

Fields

capability_id: String
operation: String


MissingOneBinding

A one requirement has no explicit provider.

Fields

consumer_instance: String
capability_id: String


AmbiguousOneBinding

A one requirement has more than one explicit provider.

Fields

consumer_instance: String
capability_id: String
providers: usize


AmbiguousOptionalBinding

An optional requirement has more than one explicit provider.

Fields

consumer_instance: String
capability_id: String
providers: usize


DuplicateBinding

A provider is repeated for the same requirement.

Fields

consumer_instance: String
capability_id: String
provider_instance: String


InvalidRequestAdmission

A request Operation has an invalid bounded admission policy.

Fields

capability_id: String
operation: String
queue_capacity: usize
max_concurrency: usize


UnknownAdmissionOperation

Admission was configured for an Operation absent from the endpoint.

Fields

capability_id: String
operation: String


UnknownOperationInteraction

Interaction metadata was configured for an absent Operation.

Fields

capability_id: String
operation: String


InvalidRestartPolicy

A Plugin Instance selected an unusable finite restart policy.

Fields

instance_key: String
max_attempts: usize
window: Duration


ActivationCycle

Explicit Capability activation dependencies contain a cycle.

Fields

instances: Vec<String>